==> PSyclone-3.0.0-py3-none-any.whl: psyclone/tests/test_files/dynamo0p3/4.17_multikernel_invokes_cell_dof_builtin.f90 <==
! -----------------------------------------------------------------------------
! BSD 3-Clause License
!
! Copyright (c) 2024, Science and Technology Facilities Council
! All rights reserved.
!
! Redistribution and use in source and binary forms, with or without
! modification, are permitted provided that the following conditions are met:
!
! * Redistributions of source code must retain the above copyright notice, this
!   list of conditions and the following disclaimer.
!
! * Redistributions in binary form must reproduce the above copyright notice,
!   this list of conditions and the following disclaimer in the documentation
!   and/or other materials provided with the distribution.
!
! * Neither the name of the copyright holder nor the names of its
!   contributors may be used to endorse or promote products derived from
!   this software without specific prior written permission.
!
! THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
! "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
! LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
! FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
! COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
! INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
! BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
! LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
! CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
! LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
! ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
! POSSIBILITY OF SUCH DAMAGE.
! -----------------------------------------------------------------------------
! Author O. Brunt, Met Office

program multikernel_invokes_cell_dof_builtin

  ! Description: Two user-defined kernels operating over different domains
  ! ("cell-column" and "dof"), followed by an LFRic built-in kernel in the
  ! same invoke.
  use constants_mod,      only: r_def
  use field_mod,          only: field_type
  use testkern_dofs_mod,  only: testkern_dofs_type
  use testkern_mod,       only: testkern_type

  implicit none

  type(field_type) :: f1, f2, f3, f4, m1, m2
  real(kind=r_def) :: a, scalar_arg

  call invoke(                                         &
       testkern_dofs_type(f1, f2, f3, f4, scalar_arg), &
       testkern_type(a, f1, f2, m1, m2),               &
       inc_aX_plus_Y(0.5_r_def, f1, f2)                &
          )

end program multikernel_invokes_cell_dof_builtin

==> PSyclone-3.1.0-py3-none-any.whl: psyclone/tests/test_files/dynamo0p3/4.17_multikernel_invokes_cell_dof_builtin.f90 <==
! -----------------------------------------------------------------------------
! BSD 3-Clause License
!
! Copyright (c) 2024-2025, Science and Technology Facilities Council
! All rights reserved.
!
! Redistribution and use in source and binary forms, with or without
! modification, are permitted provided that the following conditions are met:
!
! * Redistributions of source code must retain the above copyright notice, this
!   list of conditions and the following disclaimer.
!
! * Redistributions in binary form must reproduce the above copyright notice,
!   this list of conditions and the following disclaimer in the documentation
!   and/or other materials provided with the distribution.
!
! * Neither the name of the copyright holder nor the names of its
!   contributors may be used to endorse or promote products derived from
!   this software without specific prior written permission.
!
! THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
! "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
! LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
! FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
! COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
! INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
! BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
! LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
! CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
! LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
! ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
! POSSIBILITY OF SUCH DAMAGE.
! -----------------------------------------------------------------------------
! Author O. Brunt, Met Office
! Modified A. Pirrie, Met Office

program multikernel_invokes_cell_dof_builtin

  ! Description: Two user-defined kernels operating over different domains
  ! ("cell-column" and "dof"), followed by an LFRic built-in kernel in the
  ! same invoke.
  use constants_mod,      only: r_def
  use field_mod,          only: field_type
  use testkern_dofs_mod,  only: testkern_dofs_type
  use testkern_mod,       only: testkern_type

  implicit none

  type(field_type) :: f1, f2, f3, f4, m1, m2
  type(field_type) :: field_vec(3)
  real(kind=r_def) :: a, scalar_arg

  call invoke(                                                    &
       testkern_dofs_type(f1, f2, f3, f4, field_vec, scalar_arg), &
       testkern_type(a, f1, f2, m1, m2),                          &
       inc_aX_plus_Y(0.5_r_def, f1, f2)                           &
          )

end program multikernel_invokes_cell_dof_builtin
